@@ -1,8 +1,12 @@
+import enum
 import types
 import typing
 
 PWN = typing.TypeVar('PWN')
 
+class CassandraKeyspaceStrategy(enum.Enum):
+    Simple: str = 'SimpleStrategy'
+
 class Transliterator(typing.NamedTuple):
     cql_type: str
     python_to_cql: types.FunctionType
@@ -16,11 +20,6 @@ class CORMDetails(typing.NamedTuple):
     field_transliterators: typing.List[Transliterator]
     pk_fields: typing.List[str]
 
-    def as_create_keyspace_cql(self: PWN) -> str:
-        sql = [f'CREATE KEYSPACE IF NOT EXISTS {self.keyspace} WITH REPLICATION = ']
-        sql.append("{'class': 'NetworkTopologyStrategy', 'datacenter1': 3};")
-        return ''.join(sql)
-
     def as_create_table_cql(self: PWN) -> str:
         entries = []
         for idx, field_name in enumerate(self.field_names):
